|PyPI| |Docs|

.. |PyPI| image:: https://img.shields.io/pypi/v/novosparc.svg
   :target: https://pypi.org/project/novosparc/
.. |Docs| image:: https://readthedocs.org/projects/novosparc-nukappa/badge/?version=latest
   :target: https://novosparc-nukappa.readthedocs.io/en/latest/

novoSpaRc - *de novo* Spatial Reconstruction of Single-Cell Gene Expression
===========================================================================

.. image:: https://raw.githubusercontent.com/nukappa/nukappa.github.io/master/images/novosparc.png
   :width: 90px
   :align: left

``novoSpaRc`` predicts locations of single cells in space by solely using 
single-cell RNA sequencing data. An existing reference database of marker genes
is not required, but significantly enhances performance if available.

``novoSpaRc`` accompanies the following publication:

    | *Charting a tissue from single-cell transcriptomes*
    | M. Nitzan, N. Karaiskos, N. Friedman, N. Rajewsky
    | `bioRxiv 456350 <https://www.biorxiv.org/content/biorxiv/early/2018/10/30/456350.full.pdf>`_

Read the `documentation <https://novosparc-nukappa.readthedocs.io/en/latest/>`_ for more information.
